## What is GenJAXMix?
GenJAXMix is Dirichlet Process Mixture Modeling framework written in the JAX-accelerated probabilistic programming language `GenJAX`. Thus it provides a fast implementation to model and infer clusters using DPMMs on the GPU using clean *Genial* programs.

## Quickstart
Currently GenJAXMix is currently *private*, so please install it directly from Github:

```
pip install git+git@github.com:OpenGen/genjaxmix.git
```

## For Developers
GenJAXMix uses `uv` for package management and development. To set up GenJAXMix for development, please install `uv` and run
```
uv sync
```
